<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/tiled/aboutdialog.ui" line="+14"/>
        <source>About Tiled</source>
        <translation>A propos de Tiled</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/tiled/aboutdialog.cpp" line="+32"/>
        <source>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled Map Editor&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;Version %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(see the AUTHORS file for a full list of contributors)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;You may modify and redistribute this program under the terms of the GPL (version 2 or later). A copy of the GPL is contained in the &apos;COPYING&apos; file distributed with Tiled.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;
</source>
        <translation>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled Map Editor&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;Version %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(Voir le fichier AUTHORS pour la liste complète des contributeurs.)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Il vous est possible de modifier et de redistribuer ce programme selon les termes de la license GPL (version 2 ou supérieure). Une copie de la GPL est présente dans le fichier &apos;COPYING&apos; distribué avec Tiled.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;
</translation>
    </message>
</context>
<context>
    <name>CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.ui" line="+14"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>&amp;Save map before executing</source>
        <translation>&amp;Sauvegarder la carte avant d&apos;exécuter</translation>
    </message>
    <message>
        <source>Save map before executing</source>
        <translation type="obsolete">Sauvegarder la carte avant exécution</translation>
    </message>
</context>
<context>
    <name>Droidcraft::DroidcraftPlugin</name>
    <message>
        <location filename="../src/plugins/droidcraft/droidcraftplugin.cpp" line="+56"/>
        <source>This is not a valid Droidcraft map file!</source>
        <translation>Ce fichier n&apos;est pas une carte Droidcraft valide !</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>The map needs to have exactly one tile layer!</source>
        <translation>La carte doit avoir exactement un seul calque !</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>The layer must have a size of 48 x 48 tiles!</source>
        <translation>Les tiles du calque doivent de la taille de de 48 par 48 !</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Could not open file for writing.</source>
        <translation>La tentative d&apos;écriture du fichier a échoué.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Droidcraft map files (*.dat)</source>
        <translation>Cartes Droidcraft (*.dat)</translation>
    </message>
</context>
<context>
    <name>Lua::LuaPlugin</name>
    <message>
        <location filename="../src/plugins/lua/luaplugin.cpp" line="+46"/>
        <source>Could not open file for writing.</source>
        <translation>La tentative d&apos;écriture du fichier a échoué.</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Lua files (*.lua)</source>
        <translation>Fichier Lua (*.lua)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.ui" line="+17"/>
        <source>Tiled</source>
        <translation>Tiled</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Recent Files</source>
        <translation>&amp;Ouverts récemment</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edition</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Map</source>
        <translation>&amp;Cartes</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;View</source>
        <translation>&amp;Vue</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation type="obsolete">&amp;Calques</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Main Toolbar</source>
        <translation>Barre d&apos;outils principale</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Open...</source>
        <translation>&amp;Ouvrir...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copier</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Paste</source>
        <translation>Co&amp;ller</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;About Tiled</source>
        <translation>&amp;A propos de Tiled</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>About Qt</source>
        <translation>A propos de Qt</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Resize Map...</source>
        <translation>&amp;Redimensionner la carte...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map &amp;Properties...</source>
        <translation>&amp;Propriétés...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>AutoMap</source>
        <translation>AutoMap</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Show &amp;Grid</source>
        <translation>Voir la &amp;grille</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Save &amp;As...</source>
        <translation>Enregistrer &amp;sous...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;New...</source>
        <translation>&amp;Nouveau...</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Save As &amp;Image...</source>
        <translation>Sauvegarder en tant qu&apos;&amp;image...</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>&amp;Export As...</source>
        <translation>&amp;Exporter en tant que...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Add External Tileset...</source>
        <translation>&amp;Ajouter un Tileset externe...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Snap to Grid</source>
        <translation>&amp;Suivre la grille</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>C&amp;lose All</source>
        <translation>&amp;Tout fermer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Shift+W</source>
        <translation></translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">Monter le calque courant</translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">&amp;Descendre le calque courant</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="obsolete">&amp;Tout sélectionner</translation>
    </message>
    <message>
        <source>Select &amp;None</source>
        <translation type="obsolete">Tout &amp;désélectionner</translation>
    </message>
    <message>
        <source>New...</source>
        <translation type="obsolete">Nouveau...</translation>
    </message>
    <message>
        <location line="-113"/>
        <source>New &amp;Tileset...</source>
        <translation>Nouveau &amp;Tileset...</translation>
    </message>
    <message>
        <source>&amp;Remove Layer</source>
        <translation type="obsolete">&amp;Supprimer le calque</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">&amp;Ajouter un calque...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">&amp;Calque d&apos;objets...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Layer</source>
        <translation type="obsolete">&amp;Dupliquer le calque</translation>
    </message>
    <message>
        <source>Layer &amp;Properties...</source>
        <translation type="obsolete">&amp;Propriétés du calque...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom In</source>
        <translation>Zoomer</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom Out</source>
        <translation>Dézoomer</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Normal Size</source>
        <translation>Taille Normale</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>Save As Image...</source>
        <translation type="obsolete">Enregistrer en tant qu&apos;image...</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Couper</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Offset Map...</source>
        <translation>&amp;Gérer le décalage de la carte...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Offsets everything in a layer</source>
        <translation>Décalage du calque</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Pre&amp;ferences...</source>
        <translation>&amp;Préférences...</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Clear Recent Files</source>
        <translation>Effacer les fichiers récemment ouverts</translation>
    </message>
</context>
<context>
    <name>MapObjectItem</name>
    <message>
        <source>&amp;Duplicate</source>
        <translation type="obsolete">&amp;Dupliquer</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Effacer</translation>
    </message>
    <message>
        <source>&amp;Properties...</source>
        <translation type="obsolete">&amp;Propriétés...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Object</source>
        <translation type="obsolete">&amp;Dupliquer l&apos;objet</translation>
    </message>
    <message>
        <source>&amp;Remove Object</source>
        <translation type="obsolete">&amp;Supprimer l&apos;objet</translation>
    </message>
    <message>
        <source>Object &amp;Properties...</source>
        <translation type="obsolete">&amp;Propriétés...</translation>
    </message>
</context>
<context>
    <name>MapReader</name>
    <message>
        <location filename="../src/libtiled/mapreader.cpp" line="+130"/>
        <source>Not a map file.</source>
        <translation>Le fichier ne possède pas un format valide.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Not a tileset file.</source>
        <translation>Le fichier ne correspond pas à un tileset valide.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>%3

Line %1, column %2</source>
        <translation>%3

Ligne %1, colonne %2</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File not found: %1</source>
        <translation>Fichier introuvable : %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unable to read file: %1</source>
        <translation>Impossible de lire le fichier : %1</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation>Orientation de carte non supporté : &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation>Paramètres invalides pour le tileset &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation>Erreur lors du chargement du tileset  &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Invalid tile ID: %1</source>
        <translation>ID de tile invalide : %1</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation>Erreur lors du chargement de l&apos;image du tileset :
&apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Too many &lt;tile&gt; elements</source>
        <translation>Trop d&apos;éléments &lt;tile&gt; à charger</translation>
    </message>
    <message>
        <location line="+11"/>
        <location line="+72"/>
        <location line="+39"/>
        <location line="+90"/>
        <source>Invalid tile: %1</source>
        <translation>Tile invalide : %1</translation>
    </message>
    <message>
        <location line="-181"/>
        <source>Unknown encoding: %1</source>
        <translation>Encodage inconnu : %1</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation>Méthode de compression non supportée : &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+39"/>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation>Données du calque &apos;%1&apos; corrompues</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation>Impossible de lire le tile en position (%1,%2) sur le calque &apos;%3&apos;</translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">ID de tile globale invalide (plus petit que 0): %1</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile used but no tilesets specified</source>
        <translation>Un tile sans tileset correspondant est utilisé</translation>
    </message>
    <message>
        <location filename="../src/libtiled/mapwriter.cpp" line="+101"/>
        <source>Could not open file for writing.</source>
        <translation>La tentative d&apos;écriture du fichier a échoué.</translation>
    </message>
</context>
<context>
    <name>NewImageLayerDialog</name>
    <message>
        <location filename="../src/tiled/newimagelayerdialog.ui" line="+14"/>
        <source>New Tileset</source>
        <translation>Nouveau Tileset</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image layer</source>
        <translation>Calque d&apos;image</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation>&amp;Nom :</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation>Image :</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Rechercher...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation>Utiliser la transparence :</translation>
    </message>
</context>
<context>
    <name>NewMapDialog</name>
    <message>
        <location filename="../src/tiled/newmapdialog.ui" line="+14"/>
        <source>New Map</source>
        <translation>Nouvelle carte</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map size</source>
        <translation>Taille de la carte</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+55"/>
        <source>Width:</source>
        <translation>Largeur :</translation>
    </message>
    <message>
        <location line="-32"/>
        <location line="+55"/>
        <source>Height:</source>
        <translation>Hauteur :</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Tile size</source>
        <translation>Taille des éléments (Tiles)</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Map</source>
        <translation>Carte</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Orientation:</source>
        <translation>Orientation :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Orthogonal</source>
        <translation>Orthogonale</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Isometric</source>
        <translation>Isométrique</translation>
    </message>
</context>
<context>
    <name>NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.ui" line="+6"/>
        <source>New Tileset</source>
        <translation>Nouveau Tileset</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tileset</source>
        <translation>Tileset</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation>&amp;Nom :</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation>Image :</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Rechercher...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation>Utiliser la transparence :</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tiles</source>
        <translation>Eléments (Tiles)</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tile width:</source>
        <translation>Largeur :</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Margin:</source>
        <translation>Marge :</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile height:</source>
        <translation>Hauteur :</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spacing:</source>
        <translation>Espacement :</translation>
    </message>
</context>
<context>
    <name>ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.ui" line="+26"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Type:</source>
        <translation>Type :</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X :</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation>Y :</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Largeur :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translation>Hauteur :</translation>
    </message>
</context>
<context>
    <name>OffsetMapDialog</name>
    <message>
        <location filename="../src/tiled/offsetmapdialog.ui" line="+17"/>
        <source>Offset Map</source>
        <translation>Décalage de la carte</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Offset Contents of Map</source>
        <translation>Décalage du contenu de la carte</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X :</translation>
    </message>
    <message>
        <location line="+23"/>
        <location line="+43"/>
        <source>Wrap</source>
        <translation>Résorber</translation>
    </message>
    <message>
        <location line="-36"/>
        <source>Y:</source>
        <translation>Y :</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Layers:</source>
        <translation>Calques :</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>All Visible Layers</source>
        <translation>Tous les calques visibles</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>All Layers</source>
        <translation>Tous les calques</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Selected Layer</source>
        <translation>Calque sélectionné</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Bounds:</source>
        <translation>Bords :</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Whole Map</source>
        <translation>Carte complète</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Current Selection</source>
        <translation>Sélection actuelle</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.ui" line="+14"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Saving and Loading</source>
        <translation>Sauvegarder et charger</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Store tile layer data as:</source>
        <translation>&amp;Enregistrer les données du calque en tant que :</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>XML</source>
        <translation>XML</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (uncompressed)</source>
        <translation>Base64 (non compressé)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (gzip compressed)</source>
        <translation>Base64 (compressé par gzip)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (zlib compressed)</source>
        <translation>Base64 (compressé par zlib)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>CSV</source>
        <translation>CSV</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Reload tileset images when they change</source>
        <translation>&amp;Recharger les image de tilesets lorsqu&apos;elles sont modifiées</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Not enabled by default since a reference to an external DTD is known to cause problems with some XML parsers.</source>
        <translation>Désactivé par défaut car les références DTD externes peuvent poser des problèmes avec certains interprèteurs XML.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Include &amp;DTD reference in saved maps</source>
        <translation>&amp;Inclure la référence DTD dans le fichier</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Language:</source>
        <translation>&amp;Langue :</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Hardware &amp;accelerated drawing (OpenGL)</source>
        <translation>Utilisation de l&apos;&amp;accélération matérielle (OpenGL)</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.ui" line="+14"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Bucket Fill Tool</source>
        <translation type="obsolete">Outil de remplissage</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../src/tiled/resizedialog.ui" line="+14"/>
        <source>Resize</source>
        <translation>Redimensionner</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Largeur :</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>Hauteur :</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset</source>
        <translation>Décalage</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X :</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation>Y :</translation>
    </message>
</context>
<context>
    <name>SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.ui" line="+14"/>
        <source>Save As Image</source>
        <translation>Sauvegarder en tant qu&apos;image</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Location</source>
        <translation>Emplacement</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Rechercher...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Settings</source>
        <translation>Configuration</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Only include &amp;visible layers</source>
        <translation>&amp;Inclure uniquement les calques visibles</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Use current &amp;zoom level</source>
        <translation>Utiliser le &amp;Zoom actuel</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Draw tile grid</source>
        <translation>&amp;Afficher la grille</translation>
    </message>
</context>
<context>
    <name>Tengine::TenginePlugin</name>
    <message>
        <location filename="../src/plugins/tengine/tengineplugin.cpp" line="+50"/>
        <source>Could not open file for writing.</source>
        <translation>La tentative d&apos;écriture du fichier a échoué.</translation>
    </message>
    <message>
        <location line="+243"/>
        <source>T-Engine4 map files (*.lua)</source>
        <translation>Fichiers de cartes T-Engine4 (*.lua)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AbstractObjectTool</name>
    <message numerus="yes">
        <location filename="../src/tiled/abstractobjecttool.cpp" line="+134"/>
        <location line="+54"/>
        <source>Duplicate %n Object(s)</source>
        <translation>
            <numerusform>Dupliquer %n objet</numerusform>
            <numerusform>Dupliquer %n objets</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-53"/>
        <location line="+71"/>
        <source>Remove %n Object(s)</source>
        <translation>
            <numerusform>Effacer %n objet</numerusform>
            <numerusform>Effacer %n objets</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-62"/>
        <location line="+72"/>
        <source>Move %n Object(s) to Layer</source>
        <translation>
            <numerusform>Déplacer %n objet vers le calque</numerusform>
            <numerusform>Déplacer %n objets vers le calque</numerusform>
        </translation>
    </message>
    <message>
        <location line="-62"/>
        <source>Object &amp;Properties...</source>
        <translation>&amp;Propriétés de l&apos;objet...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutoMapper</name>
    <message>
        <location filename="../src/tiled/automap.cpp" line="+116"/>
        <source>Multiple layers %1 found!</source>
        <translation>Calques multiples trouvés pour %1 !</translation>
    </message>
    <message>
        <location line="+110"/>
        <source>No ruleRegions layer found!</source>
        <translation>Le calque &apos;ruleRegions&apos; n&apos;a pas été trouvé !</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No set layers found!</source>
        <translation>Le calque &apos;set&apos; n&apos;a pas été trouvé !</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No ruleSet layer found!</source>
        <translation>Le calque &apos;ruleSet&apos; n&apos;a pas été trouvé !</translation>
    </message>
    <message>
        <location line="+212"/>
        <source>Tile</source>
        <translation>Tile (tuile)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutomaticMappingManager</name>
    <message>
        <location line="+497"/>
        <source>No set layer found!</source>
        <translation>Le calque &apos;set&apos; n&apos;a pas été trouvé !</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Apply AutoMap rules</source>
        <translation>Appliquer les règles AutoMap</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>No rules file found at:
%1</source>
        <translation>Aucun fichier de règles trouvé à la ligne : %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Error opening rules file:
%1</source>
        <translation>Erreur lors de la tentative d&apos;ouverture du fichier de règles : %1</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>File not found:
%1</source>
        <translation>Aucun fichier trouvé sous le nom : %1</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Opening rules map failed:
%1</source>
        <translation>L&apos;ouverture de la carte de règles à échoué : %1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::BucketFillTool</name>
    <message>
        <location filename="../src/tiled/bucketfilltool.cpp" line="+39"/>
        <location line="+133"/>
        <source>Bucket Fill Tool</source>
        <translation>Outil de remplissage</translation>
    </message>
    <message>
        <location line="-130"/>
        <location line="+131"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandButton</name>
    <message>
        <location filename="../src/tiled/commandbutton.cpp" line="+39"/>
        <source>Execute Command</source>
        <translation>Exécuter la commande</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Error Executing Command</source>
        <translation>Erreur lors de l&apos;exécution de la commande</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>You do not have any commands setup.</source>
        <translation>Vous n&apos;avez configuré aucune commandes.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Edit commands...</source>
        <translation>Editer les commandes...</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Edit Commands...</source>
        <translation>Editer les commandes...</translation>
    </message>
    <message>
        <source>There was an error running the command</source>
        <translation type="obsolete">Une erreur est survenue lors de l&apos;exécution de la commande</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDataModel</name>
    <message>
        <location filename="../src/tiled/commanddatamodel.cpp" line="+60"/>
        <source>Open in text editor</source>
        <translation>Ouvrir dans l&apos;éditeur de texte</translation>
    </message>
    <message>
        <location line="+92"/>
        <location line="+67"/>
        <source>&lt;new command&gt;</source>
        <translation>&lt;Nouvelle commande&gt;</translation>
    </message>
    <message>
        <location line="-59"/>
        <source>Set a name for this command</source>
        <translation>Donner un nom à cette commande</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Set the shell command to execute</source>
        <translation>Définir la commande shell à exécuter</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Show or hide this command in the command list</source>
        <translation>Afficher ou cacher la commande dans la liste de commandes</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Add a new command</source>
        <translation>Ajouter une nouvelle commande</translation>
    </message>
    <message>
        <location line="+101"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Move Up</source>
        <translation>Déplacer vers le haut</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move Down</source>
        <translation>Déplacer vers le bas</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Execute</source>
        <translation>Exécuter</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Execute in Terminal</source>
        <translation>Exécuter dans une console de commande</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Delete</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location line="+84"/>
        <source>%1 (copy)</source>
        <translation>%1 (copie)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>New command</source>
        <translation>Nouvelle commande</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.cpp" line="+40"/>
        <source>Edit Commands</source>
        <translation>Editer les commandes</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandProcess</name>
    <message>
        <location filename="../src/tiled/command.cpp" line="+122"/>
        <source>Unable to create/open %1</source>
        <translation>Impossible de créer/ouvrir %1</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Unable to add executable permissions to %1</source>
        <translation>Impossible de rendre %1 exécutable</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>The command failed to start.</source>
        <translation>La commande n&apos;a pas démarré.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>The command crashed.</source>
        <translation>La commande a crashé.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>The command timed out.</source>
        <translation>La commande s&apos;est stoppée suite à un Time out.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>An unknown error occurred.</source>
        <translation>Une erreur inconnue s&apos;est produite.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Executing %1</source>
        <translation>Erreur lors de l&apos;exécution de %1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CreateObjectTool</name>
    <message>
        <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
        <location line="+100"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Insert Objects</source>
        <translation>Insérer des objets</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Insert Tile Objects</source>
        <translation>Insérer des objet-tiles</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>T</source>
        <translation>T</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::Eraser</name>
    <message>
        <location filename="../src/tiled/eraser.cpp" line="+34"/>
        <location line="+36"/>
        <source>Eraser</source>
        <translation>Gomme</translation>
    </message>
    <message>
        <location line="-33"/>
        <location line="+34"/>
        <source>E</source>
        <translation>E</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ImageLayerPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+60"/>
        <source>Image Layer</source>
        <translation>Calque d&apos;image</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Browse...</source>
        <translation>Rechercher...</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image:</source>
        <translation>Image :</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Transparent color:</source>
        <translation>Couleur transparente :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Layer Image</source>
        <translation>Image du calque</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerDock</name>
    <message>
        <location filename="../src/tiled/layerdock.cpp" line="+179"/>
        <source>Layers</source>
        <translation>Calques</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Opacity:</source>
        <translation>Opacité :</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerModel</name>
    <message>
        <location filename="../src/tiled/layermodel.cpp" line="+122"/>
        <source>Layer</source>
        <translation>Calques</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">Propriétés...</translation>
    </message>
    <message>
        <source>Layer</source>
        <translation type="obsolete">Calque</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.cpp" line="+134"/>
        <location line="+8"/>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location line="-7"/>
        <location line="+6"/>
        <source>Redo</source>
        <translation>Rétablir</translation>
    </message>
    <message>
        <source>Error while opening map</source>
        <translation type="obsolete">Erreur lors de l&apos;ouverture de la carte</translation>
    </message>
    <message>
        <location line="+418"/>
        <source>Open Map</source>
        <translation>Ouvrir une carte</translation>
    </message>
    <message>
        <location line="-13"/>
        <location line="+76"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>Fichiers de cartes au format Tiled (*.tmx)</translation>
    </message>
    <message>
        <source>Error while saving map</source>
        <translation type="obsolete">Erreur lors de la sauvegarde de la carte</translation>
    </message>
    <message>
        <location line="-451"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location line="+22"/>
        <location line="+1047"/>
        <source>&amp;Layer</source>
        <translation>&amp;Calques</translation>
    </message>
    <message>
        <location line="-910"/>
        <source>Ctrl+PgUp</source>
        <translatorcomment>Do not translate shortcuts!!   Ne surtout pas traduire les raccourcis !! Utiliser les mêmes idiomes anglais si le raccourcis devait être changé.</translatorcomment>
        <translation>Ctrl+PgUp</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Ctrl+PgDown</source>
        <translatorcomment>Do not translate shortcuts!!   Ne surtout pas traduire les raccourcis !! Utiliser les mêmes idiomes anglais si le raccourcis devait être changé.</translatorcomment>
        <translation>Ctrl+PgDown</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Error Opening Map</source>
        <translation>Erreur lors de l&apos;ouverture de la carte</translation>
    </message>
    <message>
        <location line="+73"/>
        <location line="+135"/>
        <source>All Files (*)</source>
        <translation>Tous les fichiers (*)</translation>
    </message>
    <message>
        <location line="-94"/>
        <location line="+141"/>
        <source>Error Saving Map</source>
        <translation>Erreur lors de la sauvegarde de la carte</translation>
    </message>
    <message>
        <location line="-108"/>
        <source>untitled.tmx</source>
        <translation>sans-titre.tmx</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Unsaved Changes</source>
        <translation>Changements non sauvegardés</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>There are unsaved changes. Do you want to save now?</source>
        <translation>Certains changements n&apos;ont pas été enregistrés. Voulez-vous les sauvegarder maintenant ?</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Export As...</source>
        <translation>Exporter en tant que...</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Unknown File Format</source>
        <translation>Format de fichier inconnu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The given filename does not have any known file extension.</source>
        <translation>Le fichier ne possède aucune extension connue.</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Paste Objects</source>
        <translation>Coller les objets</translation>
    </message>
    <message>
        <location line="+370"/>
        <source>[*]%1 - Tiled</source>
        <translation>[*]%1 - Tiled</translation>
    </message>
    <message>
        <source>Add Tilesets</source>
        <translation type="obsolete">Ajouter des tilesets</translation>
    </message>
    <message>
        <location line="-291"/>
        <source>Add External Tileset</source>
        <translation>Ajouter un tileset externe</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>Tiled - Tilesets externes (*.tsx)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Reading Tileset</source>
        <translation>Erreur lors de la lecture du tileset</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Map</source>
        <translation>Carte</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Automatic Mapping</source>
        <translation>Mapping automatique</translation>
    </message>
    <message>
        <location line="+120"/>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
    <message>
        <source>Add Tile Layer</source>
        <translation type="obsolete">Ajouter un calque simple</translation>
    </message>
    <message>
        <source>Add Object Layer</source>
        <translation type="obsolete">Ajouter un calque d&apos;objets</translation>
    </message>
    <message>
        <source>Layer name:</source>
        <translation type="obsolete">Nom du calque :</translation>
    </message>
    <message>
        <source>New Layer</source>
        <translation type="obsolete">Nouveau calque</translation>
    </message>
    <message>
        <source>Layer</source>
        <translation type="obsolete">Calque</translation>
    </message>
    <message>
        <source>%1[*] - Tiled</source>
        <translation type="obsolete">%1[*] - Tiled</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocument</name>
    <message>
        <location filename="../src/tiled/mapdocument.cpp" line="+133"/>
        <source>untitled.tmx</source>
        <translation>sans-titre.tmx</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Resize Map</source>
        <translation>Redimensionner la carte</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset Map</source>
        <translation>Décalage de carte</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile Layer %1</source>
        <translation>Calque %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Object Layer %1</source>
        <translation>Calque d&apos;objets %1</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Copy of %1</source>
        <translation>Copie de %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Duplicate Layer</source>
        <translation>Dupliquer le calque</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Merge Layer Down</source>
        <translation>Fusionner le calque vers le bas</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>Tile</source>
        <translation>Tile (tuile)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Tileset Changes</source>
        <translation>Modifications du tileset</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocumentActionHandler</name>
    <message>
        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+126"/>
        <source>Select &amp;All</source>
        <translation>&amp;Tout sélectionner</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;None</source>
        <translation>Tout &amp;désélectionner</translation>
    </message>
    <message>
        <location line="-81"/>
        <source>Ctrl+Shift+A</source>
        <translation></translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">&amp;Ajouter un calque...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">&amp;Calque d&apos;objets...</translation>
    </message>
    <message>
        <location line="+87"/>
        <source>&amp;Duplicate Layer</source>
        <translation>&amp;Dupliquer le calque</translation>
    </message>
    <message>
        <location line="-79"/>
        <source>Ctrl+Shift+D</source>
        <translation></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>PgUp</source>
        <translatorcomment>Do not translate shortcuts!!   Ne surtout pas traduire les raccourcis !! Utiliser les mêmes idiomes anglais si le raccourcis devait être changé.</translatorcomment>
        <translation>PgUp</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>PgDown</source>
        <translatorcomment>Do not translate shortcuts!!   Ne surtout pas traduire les raccourcis !! Utiliser les mêmes idiomes anglais si le raccourcis devait être changé.</translatorcomment>
        <translation>PgDown</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+Shift+H</source>
        <translatorcomment>Do not translate shortcuts!!   Ne surtout pas traduire les raccourcis !! Utiliser les mêmes idiomes anglais si le raccourcis devait être changé.</translatorcomment>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>&amp;Crop to Selection</source>
        <translation>&amp;Rogner vers la sélection</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Add &amp;Tile Layer</source>
        <translation>Ajouter un calque de &amp;tile</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Add &amp;Object Layer</source>
        <translation>Ajouter un calque d&apos;&amp;objet</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Merge Layer Down</source>
        <translation>&amp;Fusionner le cakque vers le bas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Remove Layer</source>
        <translation>&amp;Supprimer le calque</translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">&amp;Monter le calque courant</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Ctrl+Shift+Up</source>
        <translation></translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">&amp;Descendre le calque courant</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Ctrl+Shift+Down</source>
        <translation></translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Select Pre&amp;vious Layer</source>
        <translation>Sélectionner le calque préce&amp;dent</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;Next Layer</source>
        <translation>Sélectionner le calque sui&amp;vant</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>R&amp;aise Layer</source>
        <translation>M&amp;onter le calque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Lower Layer</source>
        <translation>Des&amp;cendre le calque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show/&amp;Hide all Other Layers</source>
        <translation>Montrer/Cac&amp;her tous les autres calques</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer &amp;Properties...</source>
        <translation>&amp;Propriétés du calque...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewMapDialog</name>
    <message>
        <source>Layer 1</source>
        <translation type="obsolete">Calque 1</translation>
    </message>
    <message>
        <location filename="../src/tiled/newmapdialog.cpp" line="+81"/>
        <source>Tile Layer 1</source>
        <translation>Calque 1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.cpp" line="+123"/>
        <location line="+7"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Failed to load tileset image &apos;%1&apos;.</source>
        <translation>Impossible de charger le tileset &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No tiles found in the tileset image when using the given tile size, margin and spacing!</source>
        <translation>Aucun tile trouvé dans l&apos;image en utilisant la taille, la marge et l&apos;espacement donné !</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tileset Image</source>
        <translation>Image du tileset</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectGroupPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+43"/>
        <source>Object Layer</source>
        <translation>Calque d&apos;objet</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Couleur :</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.cpp" line="+41"/>
        <source>Object</source>
        <translation>Objet</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nom :</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Type :</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Change Object</source>
        <translation>Changer d&apos;objet</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectSelectionTool</name>
    <message>
        <location filename="../src/tiled/objectselectiontool.cpp" line="+98"/>
        <location line="+110"/>
        <source>Select Objects</source>
        <translation>Sélectionner les objets</translation>
    </message>
    <message>
        <location line="-108"/>
        <location line="+109"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message numerus="yes">
        <source>Duplicate %n Object(s)</source>
        <translation type="obsolete">
            <numerusform>Dupliquer %n objet</numerusform>
            <numerusform>Dupliquer %n objets</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Remove %n Object(s)</source>
        <translation type="obsolete">
            <numerusform>Effacer %n objet</numerusform>
            <numerusform>Effacer %n objets</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Move %n Object(s) to Layer</source>
        <translation type="obsolete">
            <numerusform>Déplacer %n objet vers le calque</numerusform>
            <numerusform>Déplacer %n objets vers le calque</numerusform>
        </translation>
    </message>
    <message>
        <source>Object &amp;Properties...</source>
        <translation type="obsolete">&amp;Propriétés de l&apos;objet...</translation>
    </message>
    <message numerus="yes">
        <location line="+117"/>
        <source>Move %n Object(s)</source>
        <translation>
            <numerusform>Déplacer %n objet</numerusform>
            <numerusform>Déplacer %n objets</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.cpp" line="+56"/>
        <location line="+23"/>
        <source>System default</source>
        <translation>Réglages par défaut</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.cpp" line="+69"/>
        <source>%1 Properties</source>
        <translation>Propriétés de %1</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Layer</source>
        <translation>Calque</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesModel</name>
    <message>
        <location filename="../src/tiled/propertiesmodel.cpp" line="+51"/>
        <source>&lt;new property&gt;</source>
        <translation>&lt;Nouvelle propriété&gt;</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.cpp" line="+111"/>
        <source>Save as Image</source>
        <translation>Sauvegarder en tant qu&apos;image</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>Le fichier %1 existe déjà. Voulez-vous le remplacer ?</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SelectionTool</name>
    <message>
        <location filename="../src/tiled/selectiontool.cpp" line="+34"/>
        <location line="+81"/>
        <source>Rectangular Select</source>
        <translation>Sélection rectangulaire</translation>
    </message>
    <message>
        <location line="-78"/>
        <location line="+79"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location line="-56"/>
        <source>%1, %2 - Rectangle: (%3 x %4)</source>
        <translation>%1, %2 - Rectangle: (%3 x %4)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::StampBrush</name>
    <message>
        <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
        <location line="+281"/>
        <source>Stamp Brush</source>
        <translation>Tampon</translation>
    </message>
    <message>
        <location line="-278"/>
        <location line="+279"/>
        <source>B</source>
        <translation>B</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetDock</name>
    <message>
        <location filename="../src/tiled/tilesetdock.cpp" line="+279"/>
        <source>Remove Tileset</source>
        <translation>Effacer le tileset</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The tileset &quot;%1&quot; is still in use by the map!</source>
        <translation>Le tileset &quot;%1&quot; est toujours en cours d&apos;utilisation par la carte !</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Remove this tileset and all references to the tiles in this tileset?</source>
        <translation>Retirer ce tileset et toutes les références aux tiles dans ce tileset ?</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Tilesets</source>
        <translation>Tilesets</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">Propriétés...</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="+213"/>
        <source>Tile &amp;Properties...</source>
        <translation>&amp;Propriétés des tiles...</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Export Tileset As...</source>
        <translation>&amp;Exporter le tileset en tant que...</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Import Tileset</source>
        <translation>&amp;Importer le tileset</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show &amp;Grid</source>
        <translation>Afficher la &amp;grille</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Tile</source>
        <translation>Tile (tuile)</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Export Tileset</source>
        <translation>Exporter le tileset</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>Tiled - fichier tileset (*.tsx)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ToolManager</name>
    <message>
        <location filename="../src/tiled/toolmanager.cpp" line="+88"/>
        <source>Tools</source>
        <translation>Outils</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::UndoDock</name>
    <message>
        <location filename="../src/tiled/undodock.cpp" line="+64"/>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;empty&gt;</source>
        <translation>&lt;vide&gt;</translation>
    </message>
</context>
<context>
    <name>Tmw::TmwPlugin</name>
    <message>
        <location filename="../src/plugins/tmw/tmwplugin.cpp" line="+47"/>
        <source>Multiple collision layers found!</source>
        <translation>Plusieurs calque de collision trouvés !</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>No collision layer found!</source>
        <translation>Aucun calque de collision trouvé !</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Could not open file for writing.</source>
        <translation>La tentative d&apos;écriture du fichier a échoué.</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>TMW-eAthena collision files (*.wlk)</source>
        <translation>Fichier de collision - TMW-eathena (*.wlk)</translation>
    </message>
</context>
<context>
    <name>TmxMapReader</name>
    <message>
        <source>XML map reader (*.tmx)</source>
        <translation type="obsolete">Interprèteur de carte XML (*.tmx)</translation>
    </message>
    <message>
        <source>Could not open file for writing.</source>
        <translation type="obsolete">La tentative d&apos;écriture du fichier a échoué.</translation>
    </message>
    <message>
        <source>XML map writer (*.tmx)</source>
        <translation type="obsolete">Interprèteur de carte XML (*.tmx)</translation>
    </message>
    <message>
        <location filename="../src/tiled/tmxmapreader.h" line="+55"/>
        <location filename="../src/tiled/tmxmapwriter.h" line="+56"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>Fichiers de cartes au format Tiled (*.tmx)</translation>
    </message>
</context>
<context>
    <name>TmxReader</name>
    <message>
        <source>Not a map file.</source>
        <translation type="obsolete">Le fichier ne possède pas un format valide.</translation>
    </message>
    <message>
        <source>Not a tileset file.</source>
        <translation type="obsolete">Le fichier ne correspond pas à un tileset valide.</translation>
    </message>
    <message>
        <source>%3

Line %1, column %2</source>
        <translation type="obsolete">%3

Ligne %1, colonne %2</translation>
    </message>
    <message>
        <source>File not found: %1</source>
        <translation type="obsolete">Fichier introuvable : %1</translation>
    </message>
    <message>
        <source>Unable to read file: %1</source>
        <translation type="obsolete">Impossible de lire le fichier : %1</translation>
    </message>
    <message>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation type="obsolete">Orientation de carte non supporté : &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation type="obsolete">Paramètres invalides pour le tileset &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation type="obsolete">Erreur lors du chargement du tileset  &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <source>Invalid tile ID: %1</source>
        <translation type="obsolete">ID de tile invalide : %1</translation>
    </message>
    <message>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation type="obsolete">Erreur lors du chargement de l&apos;image du tileset :
&apos;%1&apos;</translation>
    </message>
    <message>
        <source>Too many &lt;tile&gt; elements</source>
        <translation type="obsolete">Trop de &lt;tile&gt; à charger</translation>
    </message>
    <message>
        <source>Invalid tile: %1</source>
        <translation type="obsolete">Tile invalide : %1</translation>
    </message>
    <message>
        <source>Unknown encoding: %1</source>
        <translation type="obsolete">Encodage inconnu : %1</translation>
    </message>
    <message>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation type="obsolete">Méthode de compression non supportée : &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation type="obsolete">Données du calque &apos;%1&apos; corrompues</translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">ID de tile globale invalide (plus petit que 0): %1</translation>
    </message>
    <message>
        <source>Tile used but no tilesets specified</source>
        <translation type="obsolete">Un tile sans tileset correspondant est utilisé</translation>
    </message>
</context>
<context>
    <name>TmxViewer</name>
    <message>
        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+160"/>
        <source>TMX Viewer</source>
        <translation>Visionneuse de fichier TMX</translation>
    </message>
</context>
<context>
    <name>Undo Commands</name>
    <message>
        <location filename="../src/tiled/addremovelayer.h" line="+67"/>
        <source>Add Layer</source>
        <translation>Ajouter un calque</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Remove Layer</source>
        <translation>Supprimer un calque</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovemapobject.cpp" line="+79"/>
        <source>Add Object</source>
        <translation>Ajouter un objet</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Remove Object</source>
        <translation>Supprimer un objet</translation>
    </message>
    <message>
        <location filename="../src/tiled/changemapobject.cpp" line="+35"/>
        <source>Change Object</source>
        <translation>Modifier un objet</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeobjectgroupproperties.cpp" line="+37"/>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+21"/>
        <source>Change Object Layer Properties</source>
        <translation>Modifier les propriétés du calque d&apos;objet</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeproperties.cpp" line="+34"/>
        <source>Change %1 Properties</source>
        <translation>Modifier les propriétés de %1</translation>
    </message>
    <message>
        <location filename="../src/tiled/changetileselection.cpp" line="+31"/>
        <source>Change Selection</source>
        <translation>Modifier la sélection</translation>
    </message>
    <message>
        <location filename="../src/tiled/erasetiles.cpp" line="+39"/>
        <source>Erase</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../src/tiled/filltiles.cpp" line="+36"/>
        <source>Fill Area</source>
        <translation>Remplire la zone</translation>
    </message>
    <message>
        <source>Move Layer Down</source>
        <translation type="obsolete">Descendre le calque</translation>
    </message>
    <message>
        <source>Move Layer Up</source>
        <translation type="obsolete">Monter le calque</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobject.cpp" line="+39"/>
        <source>Move Object</source>
        <translation>Déplacer l&apos;objet</translation>
    </message>
    <message>
        <location filename="../src/tiled/offsetlayer.cpp" line="+40"/>
        <source>Offset Layer</source>
        <translation>Décaler le calque</translation>
    </message>
    <message>
        <location filename="../src/tiled/painttilelayer.cpp" line="+49"/>
        <source>Paint</source>
        <translation>Dessiner</translation>
    </message>
    <message>
        <location filename="../src/tiled/renamelayer.cpp" line="+40"/>
        <source>Rename Layer</source>
        <translation>Renommer le calque</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizelayer.cpp" line="+37"/>
        <source>Resize Layer</source>
        <translation>Redimensionner le calque</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemap.cpp" line="+32"/>
        <source>Resize Map</source>
        <translation>Redimensionner la carte</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemapobject.cpp" line="+39"/>
        <source>Resize Object</source>
        <translation>Redimensionner l&apos;objet</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.cpp" line="+62"/>
        <source>Add Tileset</source>
        <translation>Ajouter un tileset</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.h" line="+78"/>
        <source>Remove Tileset</source>
        <translation>Supprimer un tileset</translation>
    </message>
    <message>
        <location filename="../src/tiled/movetileset.cpp" line="+31"/>
        <source>Move Tileset</source>
        <translation>Déplacer un tileset</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="-159"/>
        <source>Import Tileset</source>
        <translation>Importer un tileset</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Export Tileset</source>
        <translation>Exporter un tileset</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobjecttogroup.cpp" line="+40"/>
        <source>Move Object to Layer</source>
        <translation>Déplacer l&apos;objet vers le calque</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeimagelayerproperties.cpp" line="+39"/>
        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+28"/>
        <source>Change Image Layer Properties</source>
        <translation>Modifier les propriétés du calque d&apos;image</translation>
    </message>
    <message>
        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
        <source>Lower Layer</source>
        <translation>Descendre le calque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Raise Layer</source>
        <translation>Monter le calque</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/tiled/utils.cpp" line="+31"/>
        <source>Image files</source>
        <translation>Fichiers images</translation>
    </message>
</context>
</TS>
